@@ -1,11 +1,10 @@
 from __future__ import annotations
 
-import base64
 import datetime
 import logging
 import threading
 from enum import Enum, auto
-from logging import ERROR, LogRecord
+from logging import LogRecord
 from typing import Any, Dict, List, Optional, cast
 from uuid import uuid4
 
@@ -17,7 +16,7 @@ from .cwe import CWE
 from .failures import Evidence
 from .status import Status
 from .types import Headers
-from .utils import format_exception
+from .utils import base64_decode, base64_encode, format_exception
 
 
 class Payload:
@@ -109,7 +108,7 @@ class Request:
             uri=uri,
             method=method,
             headers={key: [value] for (key, value) in prepared.headers.items()},
-            body=base64.b64encode(body).decode() if body is not None else body,
+            body=base64_encode(body) if body is not None else body,
         )
 
     def as_curl_command(self) -> str:
@@ -122,16 +121,14 @@ class Request:
                 key: ";".join(value) if isinstance(value, list) else value
                 for (key, value) in self.headers.items()
             },
-            data=base64.b64decode(self.body.encode()).decode()
-            if self.body is not None
-            else self.body,
+            data=base64_decode(self.body) if self.body is not None else None,
         )
 
         return curlify.to_curl(prepared_request)
 
 
 def serialize_payload(payload: bytes) -> str:
-    return base64.b64encode(payload).decode()
+    return base64_encode(payload)
 
 
 @attr.s(slots=True, repr=False)
@@ -261,7 +258,6 @@ class Step:
             summary=summary,
         )
         self.records.append(record)
-        self.status += interaction.status
         return record
 
     def log(self, log: LogRecord, summary: Optional[str] = None) -> StepRecord:
@@ -271,8 +267,6 @@ class Step:
             summary=summary,
         )
         self.records.append(record)
-        if log.levelno > ERROR:
-            self.status = Status.error
         return record
 
 
