@@ -1,6 +1,9 @@
 import sys
 
-from levo_commons.utils import syspath_prepend
+from hypothesis import given
+from hypothesis import strategies as st
+
+from levo_commons.utils import base64_decode, base64_encode, syspath_prepend
 
 
 def test_syspath_prepend():
@@ -24,3 +27,11 @@ def test_syspath_prepend_nested():
         assert sys.path[0] == path_1
     assert path_1 not in sys.path
     assert path_2 not in sys.path
+
+
+@given(st.text())
+def test_base64_encode_decode(s):
+    assert s == base64_decode(base64_encode(s))
+    # Test with bytes type
+    b = s.encode("utf-8")
+    assert b.decode("utf-8") == base64_decode(base64_encode(b))
